@@ -1,7 +1,7 @@
 from dataclasses import dataclass, field
 from enum import Enum, unique
 
-from utils.current_timestamp import get_current_timestamp_ms
+from notification_server_connector.utils.current_timestamp import get_current_timestamp_ms
 
 
 @unique
